==> gbsite-1.1.0.tar.gz: gbsite/templates/gb/gb_prodgbpgsqlpage.php <==
<table cellpadding="4" cellspacing="0" border="0" width="100%">       
<tr>
<td width="100%" valign="top">
<font face="<?= $font_1 ?>" size="2">
<p><img src="<?= $image_path ?>/gbpgsql_box.gif" width="100" height="127" align="left" hspace="5">Great Bridge PostgreSQL is the first enhanced distribution of the world's most advanced open source database.
<br><br>
It is a QA-tested release of the PostgreSQL 7.0.3 database server for multiple Linux platforms. It includes an automated graphical installer for quick and easy installation and configuration and over 500 pages of professional-grade documentation.</p>
</font>
</td>
</tr>
<tr>
<td>
<img src="<?= $image_path ?>/shim.gif" width="1" height="10">
	<table cellpadding="2" cellspacing="2" border="0" width="100%">       
	<tr>
	<td valign="top" width="100%">
	<font face="<?= $font_1 ?>" size="2">
	<b><u>Supported Platforms</u></b>
	<br>
	<li>Red Hat Linux 6.1, 6.2, 7.0
	<li>SuSE Linux 6.4, 7.0
	<li>TurboLinux 7.0
	<li>Caldera OpenLinux eServer 2.3
	<li>Linux-Mandrake 7.2
	<br><br>
	<b><u>Key Features</u></b>
	<br>
	<li>Robust transaction support and throughput
	<li>Commercial-grade SQL support
	<li>Complex queries and indexes
	<li>Multiple interfaces supported
	<li>Common and user-defined functions
	<li>Sophisticated data integrity features
	<li>Complex data types that exceed 1992 ANSI Standard requirements
	<br><br>
	<b><u>License</u></b>
	<br>Great Bridge PostgreSQL is distributed under an open source "Berkeley-style" <a href="/product/postgresql_license.php">license</a> similar to those of the various BSD operating systems. Download Great Bridge PostgreSQL  <a href="/download/download.php">here</a>.
	</font>
	</td>
	<td valign="top" bgcolor="<?= $color_1 ?>">
		<table cellpadding="2" cellspacing="0" border="0" width="100%" bgcolor="<?= $color_4 ?>">       
		<tr bgcolor="<?= $color_4 ?>">
		<td valign="top" width="100%">
		<img src="<?= $image_path ?>/shim.gif" width="150" height="1"><br>
		<font face="<?= $font_1 ?>" size="2">
		<b><u>Product Information</u></b>
		<!--<br>
		<br><a href="/download/.pdf">Great Bridge PostgreSQL Product Spec Sheet (PDF)</a> -->
		<br>
		<br><a href="/download/gbpg70wp1.pdf">Introduction to PostgreSQL White Paper(PDF)</a>
		<br>
		<br><a href="/download/gbpg70wp2.pdf">PostgreSQL Database Administration & Tuning White Paper (PDF)</a>
		<br><br>
		<b><u>Documentation</u></b>
		<br><br>
		Installation Guide<br>&nbsp;&nbsp;<a href="/docview.php?doc=IG&fformat=PDF">PDF</a>&nbsp;|&nbsp;<a href="/docview/IG/">HTML</a>
		<br><br>
		User's Guide<br>&nbsp;&nbsp;<a href="/docview.php?doc=UG&fformat=PDF">PDF</a>&nbsp;|&nbsp;<a href="/docview/UG/">HTML</a>
		<br><br>
		Reference Guide<br>&nbsp;&nbsp;<a href="/docview.php?doc=RG&fformat=PDF">PDF</a>&nbsp;|&nbsp;<a href="/docview/RG/">HTML</a>
		<br><br><br><br>
		</font>	
		</tr>
		</td>
		</table>
	</td>
	</tr>
	</table>
</td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td>
<font face="<?= $font_1 ?>" size="2">
<b>Great Bridge PostgreSQL Services and Support</b>
<br>Great Bridge offers a broad spectrum of services and support including:</font>
	<table cellpadding="2" cellspacing="2" border="0" width="100%"> 
	<tr>
	<td>
	<font face="<?= $font_1 ?>" size="2">
	<li><a href="/product/prodtech.php">Technical Support Packages</a>
	<li><a href="/product/prodcon.php">Consulting Services</a>
	</font>
	</td>
	<td><img src="<?= $image_path ?>/shim" width="10" height="1"></td>
	<td>
	<font face="<?= $font_1 ?>" size="2">
	<li><a href="/product/proddev.php">Developer-to-Developer Support</a>
	<li><a href="/product/prodvar.php">Partner Programs</a>
	</font>
	</td>
	</tr>
	</table>
</td>
</tr>
</table>

==> gbsite-1.1.1.tar.gz: gbsite/templates/gb/gb_prodgbpgsqlpage.php <==
<table cellpadding="4" cellspacing="0" border="0" width="100%">       
<tr>
<td width="100%" valign="top">
<font face="<?= $font_1 ?>" size="2">
<p><img src="<?= $image_path ?>/gbpgsql_box.gif" width="100" height="127" align="left" hspace="10">Great Bridge PostgreSQL is the first enhanced distribution of the world's most advanced open source database.
<br><br>
It is a QA-tested release of the PostgreSQL 7.0.3 database server for multiple Linux platforms. It includes an automated graphical installer for quick and easy installation and configuration and over 500 pages of professional-grade documentation.</p>
</font>
</td>
</tr>
<tr>
<td>
<img src="<?= $image_path ?>/shim.gif" width="1" height="10">
	<table cellpadding="2" cellspacing="2" border="0" width="100%">       
	<tr>
	<td valign="top" width="100%">
	<font face="<?= $font_1 ?>" size="2">
	<b>Supported Platforms</b>
	<br>
	<li>Red Hat Linux 6.1, 6.2, 7.0
	<li>SuSE Linux 6.4, 7.0
	<li>TurboLinux 7.0
	<li>Caldera OpenLinux eServer 2.3
	<li>Linux-Mandrake 7.2
	<br><br>
	<b>Key Features</b>
	<br>
	<li>Robust transaction support and throughput
	<li>Commercial-grade SQL support
	<li>Complex queries and indexes
	<li>Multiple interfaces supported
	<li>Common and user-defined functions
	<li>Sophisticated data integrity features
	<li>Complex data types that exceed 1992 ANSI Standard requirements
	<br><br>
	<b>License</b>
	<br>Great Bridge PostgreSQL is distributed under an open source "Berkeley-style" <a href="/product/postgresql_license.php">license</a> similar to those of the various BSD operating systems. Download Great Bridge PostgreSQL  <a href="/download/download.php">here</a>.
	</font>
	</td>
	<td valign="top" bgcolor="<?= $color_6 ?>">
	<img src="<?= $image_path ?>/shim.gif" width="150" height="1"><br>
		<table cellpadding="2" cellspacing="0" border="0" width="100%" bgcolor="<?= $color_2 ?>">       
		<tr bgcolor="<?= $color_6 ?>">
		<td><font face="<?= $font_1 ?>" color="<?= $color_2 ?>" size="2"><b>Product Information</b></font></td>
		</tr>
		<tr bgcolor="<?= $color_2 ?>">
		<td valign="top" width="100%">
		<font face="<?= $font_1 ?>" size="2">
		<!--<br>
		<a href="/download/.pdf">Great Bridge PostgreSQL Product Spec Sheet (PDF)</a> -->
		<br><a href="/download/gbpg70wp1.pdf">Introduction to PostgreSQL White Paper (PDF)</a>
		<br>
		<br><a href="/download/gbpg70wp2.pdf">PostgreSQL Database Administration & Tuning White Paper (PDF)</a>
		<br><br>
		</font>
		</td>
		</tr>
		<tr bgcolor="<?= $color_6 ?>">
		<td><font face="<?= $font_1 ?>"  color="<?= $color_2 ?>" size="2"><b>Documentation</b></font></td>
		</tr>
		<tr>
		<td>
		<font face="<?= $font_1 ?>" size="2">
		<br>Installation Guide<br>&nbsp;&nbsp;<a href="/docview.php?doc=IG&fformat=PDF">PDF</a>&nbsp;|&nbsp;<a href="/docview/IG/">HTML</a>
		<br><br>
		User's Guide<br>&nbsp;&nbsp;<a href="/docview.php?doc=UG&fformat=PDF">PDF</a>&nbsp;|&nbsp;<a href="/docview/UG/">HTML</a>
		<br><br>
		Reference Guide<br>&nbsp;&nbsp;<a href="/docview.php?doc=RG&fformat=PDF">PDF</a>&nbsp;|&nbsp;<a href="/docview/RG/">HTML</a>
		<br><br><br><br>
		</font>	
		</tr>
		</td>
		</table>
	</td>
	</tr>
	</table>
</td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td>
<font face="<?= $font_1 ?>" size="2">
<b>Great Bridge PostgreSQL Services and Support</b>
<br>Great Bridge offers a broad spectrum of services and support including:</font>
	<table cellpadding="2" cellspacing="2" border="0" width="100%"> 
	<tr>
	<td>
	<font face="<?= $font_1 ?>" size="2">
	<li><a href="/product/prodtech.php">Technical Support Packages</a>
	<li><a href="/product/prodcon.php">Consulting Services</a>
	</font>
	</td>
	<td><img src="<?= $image_path ?>/shim" width="10" height="1"></td>
	<td>
	<font face="<?= $font_1 ?>" size="2">
	<li><a href="/product/proddev.php">Developer-to-Developer Support</a>
	<li><a href="/product/prodvar.php">Partner Programs</a>
	</font>
	</td>
	</tr>
	</table>
</td>
</tr>
</table>
